==> qtjambi-qt3drender-5.15.5-sources.jar: io/qt/qt3d/render/QSharedGLTexture.java <==
package io.qt.qt3d.render;


/**
 * <p>Allows to use a textureId from a separate OpenGL context in a Qt 3D scene</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3drender-qsharedgltexture.html">Qt3DRender::QSharedGLTexture</a></p>
 */
public class QSharedGLTexture extends io.qt.qt3d.render.QAbstractTexture
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QSharedGLTexture.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qsharedgltexture.html#textureId-prop">Qt3DRender::QSharedGLTexture::textureIdChanged(int)</a></p>
     */
    @io.qt.QtPropertyNotify(name="textureId")
    public final Signal1<@io.qt.QtPrimitiveType Integer> textureIdChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QSharedGLTexture(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QSharedGLTexture() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QSharedGLTexture(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QSharedGLTexture instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qsharedgltexture.html#textureId-prop">Qt3DRender::QSharedGLTexture::setTextureId(int)</a></p>
     */
    @io.qt.QtPropertyWriter(name="textureId")
    public final void setTextureId(int id){
        setTextureId_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), id);
    }
    
    private native void setTextureId_native_int(long __this__nativeId, int id);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qsharedgltexture.html#textureId-prop">Qt3DRender::QSharedGLTexture::textureId()const</a></p>
     */
    @io.qt.QtPropertyReader(name="textureId")
    @io.qt.QtUninvokable
    public final int textureId(){
        return textureId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int textureId_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QSharedGLTexture(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QSharedGLTexture(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QSharedGLTexture instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-5.15.10-sources.jar: io/qt/qt3d/render/QSharedGLTexture.java <==
package io.qt.qt3d.render;


/**
 * <p>Allows to use a textureId from a separate OpenGL context in a Qt 3D scene</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3drender-qsharedgltexture.html">Qt3DRender::QSharedGLTexture</a></p>
 */
public class QSharedGLTexture extends io.qt.qt3d.render.QAbstractTexture
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QSharedGLTexture.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qsharedgltexture.html#textureId-prop">Qt3DRender::QSharedGLTexture::textureIdChanged(int)</a></p>
     */
    @io.qt.QtPropertyNotify(name="textureId")
    public final Signal1<@io.qt.QtPrimitiveType Integer> textureIdChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QSharedGLTexture(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QSharedGLTexture() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QSharedGLTexture(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QSharedGLTexture instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qsharedgltexture.html#textureId-prop">Qt3DRender::QSharedGLTexture::setTextureId(int)</a></p>
     */
    @io.qt.QtPropertyWriter(name="textureId")
    public final void setTextureId(int id){
        setTextureId_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), id);
    }
    
    private native void setTextureId_native_int(long __this__nativeId, int id);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qsharedgltexture.html#textureId-prop">Qt3DRender::QSharedGLTexture::textureId()const</a></p>
     */
    @io.qt.QtPropertyReader(name="textureId")
    @io.qt.QtUninvokable
    public final int textureId(){
        return textureId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int textureId_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QSharedGLTexture(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QSharedGLTexture(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QSharedGLTexture instance, QDeclarativeConstructor constructor);
    
}
